︠214b50b6-dd2e-457b-bc66-cef2c93a9957s︠
# based on code from oddrobot, http://sagenb.org/home/pub/1532/
from sage.calculus.desolvers import desolve_system_rk4
x,y,t=var('x y t')
class DESolution:
    def __init__(self,system,time_range,initial,stepsize=0.05,initial_points=20):
        self.tvar=time_range[0]
        self._times=srange(time_range[1],time_range[2],stepsize)
        self.vars=[v for v,_ in initial]
        self.dim=len(self.vars)
        self._system=system
        # check to see if we need one solution or multiple solutions
        if isinstance(initial[0][1],(list,tuple)):
            # multiple initial values, from the first value of each variable to the last value of each variable
            start = vector([a for _,(a,b) in initial])
            line = vector([b for _,(a,b) in initial])-start
            self._soln = [desolve_odeint(system, ics=list(start+t*line), 
                              times=self._times, dvars=self.vars, ivar=self.tvar) for t in srange(0,1,step=1/(initial_points-1),include_endpoint=True)]
        else:
            self._soln = [desolve_odeint(system, ics=[v for _,v in initial],times=self._times, dvars=self.vars, ivar=self.tvar)]
        
    def phase_plot(self,vars=None,color='blue',**kwargs):
        # find which indices the specified variables are
        if vars is not None:
            vars_index=[self.vars.index(v) for v in vars]
        elif self.dim<=3:
            vars_index=range(self.dim)
        else:
            vars_index=range(2)
        p = Graphics()
        for s in self._soln:
            p+=line(s[:,vars_index],color=color,**kwargs)
            # add an arrow head showing which way we are going around the phase line
            half=int(s.shape[0]/2)
            p+=arrow(s[half,vars_index], s[half+1,vars_index],color='red')
        if len(vars_index)==2:
            p.axes_labels([str(self.vars[v]) for v in vars_index])
        return p
        
    def coordinates(self,colors=None,**kwargs):
        if colors is None:
            colors=rainbow(len(self.vars))
        p=Graphics()
        legend=True
        for s in self._soln:
            # only want legends the first time
            p+=sum(line(zip(self._times,s[:,i]), color=colors[i], legend_label=str(self.vars[i]) if legend else None,**kwargs) for i in range(self.dim))
            legend=False
        return p
    
    
#ADA 14 Equipo 2.
var('x,y,z')
M = matrix([[0,1,0],[0,0,1],[0,0,0]])
show(M)
show(M.eigenvectors_right())
show(M.characteristic_polynomial())
show(M.characteristic_polynomial().roots())
show(M.eigenvalues())
from sympy import Matrix
m = Matrix(3, 3, [0,1,0,0,0,1,0,0,0])
m
(P, J) = m.jordan_form()
P
J
F=[y,z,0]
solution=DESolution(F,[t,0,3.4],[[x,(-2,2)],(y,[5,-5]),[z,[-3,3]]])
solution.coordinates(['red','blue','green'])
solution.phase_plot()


︡92d25c55-7df0-499f-99bf-21f2b8f5888b︡{"stdout":"(x, y, z)\n"}︡{"html":"<div align='center'>$\\displaystyle \\left(\\begin{array}{rrr}\n0 &amp; 1 &amp; 0 \\\\\n0 &amp; 0 &amp; 1 \\\\\n0 &amp; 0 &amp; 0\n\\end{array}\\right)$</div>"}︡{"html":"<div align='center'>[($\\displaystyle 0$, [$\\displaystyle \\left(1,\\,0,\\,0\\right)$], $\\displaystyle 3$)]</div>"}︡{"html":"<div align='center'>$\\displaystyle x^{3}$</div>"}︡{"html":"<div align='center'>[($\\displaystyle 0$, $\\displaystyle 3$)]</div>"}︡{"html":"<div align='center'>[$\\displaystyle 0$, $\\displaystyle 0$, $\\displaystyle 0$]</div>"}︡{"stdout":"Matrix([\n[0, 1, 0],\n[0, 0, 1],\n[0, 0, 0]])\n"}︡{"stdout":"Matrix([\n[1, 0, 0],\n[0, 1, 0],\n[0, 0, 1]])\n"}︡{"stdout":"Matrix([\n[0, 1, 0],\n[0, 0, 1],\n[0, 0, 0]])\n"}︡{"file":{"filename":"/home/user/.sage/temp/project-56cc8ce6-3e7d-446f-b6f1-13760ee8a615/779/tmp_G6WlGn.svg","show":true,"text":null,"uuid":"6630ca2e-211d-4933-8586-c04530529b6a"},"once":false}︡{"file":{"filename":"6e7accea-cf33-46a5-b6a6-179d2187949b.sage3d","uuid":"6e7accea-cf33-46a5-b6a6-179d2187949b"}}︡{"done":true}︡
︠adcc57fc-f5bc-4406-bceb-e9ae740a8786︠

︡dfc0eac6-9743-45a3-a844-7007bea44221︡
︠6e52fd6b-11e5-4183-87cc-7c044b9c180b︠
https://cocalc.com/blobs/f32faa0f-0eaa-4b4b-b20c-a526a066ad09.svg?uuid=084d8617-e8a6-4b59-bc4b-c7d763a6e9da
x,y,z=var('x,y,z')

# Next we define the parameters
sigma=10
rho=28
beta=8/3

# The Lorenz equations
lorenz=[sigma*(y-x),x*(rho-z)-y,x*y-beta*z]

# Time and initial conditions
N=250000
tmax=250
h=tmax/N
t=srange(0,tmax+h,h)
ics=[0,1,1]
sol=desolve_odeint(lorenz,ics,t,[x,y,z],rtol=1e-13,atol=1e-14)
X=sol[:,0]
Y=sol[:,1]
Z=sol[:,2]
# Plot the result
from mpl_toolkits.mplot3d import axes3d
from matplotlib import pyplot as plt
# Call the plot function if you want to plot the data
def plot():
    fig = plt.figure(1)
    ax = fig.add_subplot(111, projection='3d')
    ax.plot_wireframe(X, Y, Z, rstride=10, cstride=10)
    ax.set_xlabel('X(t)')
    ax.set_ylabel('Y(t)')
    ax.set_zlabel('Z(t)')
    plt.show()

plot()
︡a4414098-97d0-4b18-8a7f-649dae88ffb1︡{"file":{"filename":"f32faa0f-0eaa-4b4b-b20c-a526a066ad09.svg","show":true,"text":null,"uuid":"084d8617-e8a6-4b59-bc4b-c7d763a6e9da"},"once":false}︡{"done":true}︡
︠d53bc76f-6ec6-44e5-a75f-389ed23d00c6s︠
var('a,x,y,z,w')
initial=[[x,[y,1]],[y,[z,2]],[z,[w,3]]]
p=[[x,y,z],[1,2,3]]
[v for v,_ in initial]
[a for _,(a,b) in initial]
[b for _,[_,b] in initial]
[c for _,c,_ in p]
initial[0][1]
︡87d41adb-50fb-4a33-a3c9-22fa07393092︡{"stdout":"(a, x, y, z, w)\n"}︡{"stdout":"[x, y, z]\n"}︡{"stdout":"[y, z, w]\n"}︡{"stdout":"[1, 2, 3]\n"}︡{"stdout":"[y, 2]\n"}︡{"stdout":"[y, 1]\n"}︡{"done":true}︡
︠86592671-7205-4785-854d-c462225fbbca︠









